/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * HAI 实例的网络配置和消耗情况
 */
export interface NetworkStatus {
  /**
   * HAI 的实例 ID
注意：此字段可能返回 null，表示取不到有效值。
   */
  InstanceId?: string
  /**
   * 公网 IP 地址
注意：此字段可能返回 null，表示取不到有效值。
   */
  AddressIp?: string
  /**
   * 出带宽上限，单位Mbps
注意：此字段可能返回 null，表示取不到有效值。
   */
  Bandwidth?: number
  /**
   * 流量包总量，单位GB
注意：此字段可能返回 null，表示取不到有效值。
   */
  TotalTrafficAmount?: number
  /**
   * 流量包剩余量，单位GB
注意：此字段可能返回 null，表示取不到有效值。
   */
  RemainingTrafficAmount?: number
}

/**
 * InquirePriceRunInstances返回参数结构体
 */
export interface InquirePriceRunInstancesResponse {
  /**
   * 发货参数对应的价格组合，当DryRun=True，会返回空
注意：此字段可能返回 null，表示取不到有效值。
   */
  Price?: Price
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * StopInstance请求参数结构体
 */
export interface StopInstanceRequest {
  /**
   * 实例ID
   */
  InstanceId: string
  /**
   * hai实例关机的模式，目前仅支持关机不收费：
STOP_CHARGE -- 关闭hai实例，释放计算资源，停止收取计算资源的费用。
注意：默认值为STOP_CHARGE
   */
  StopMode?: string
  /**
   * 默认为False，True代表只验证接口连通性
   */
  DryRun?: boolean
}

/**
 * DescribeServiceLoginSettings返回参数结构体
 */
export interface DescribeServiceLoginSettingsResponse {
  /**
   * 服务登录配置详情
注意：此字段可能返回 null，表示取不到有效值。
   */
  LoginSettings?: Array<LoginSetting>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeInstanceNetworkStatus返回参数结构体
 */
export interface DescribeInstanceNetworkStatusResponse {
  /**
   * 查询结果集长度
   */
  TotalCount?: number
  /**
   * 查询结果集
注意：此字段可能返回 null，表示取不到有效值。
   */
  NetworkStatusSet?: Array<NetworkStatus>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 实例信息
 */
export interface Instance {
  /**
   * 实例id
注意：此字段可能返回 null，表示取不到有效值。
   */
  InstanceId?: string
  /**
   * 实例名称
注意：此字段可能返回 null，表示取不到有效值。
   */
  InstanceName?: string
  /**
   * 实例状态：
PENDING：表示创建中
LAUNCH_FAILED：表示创建失败
RUNNING：表示运行中
ARREAR：表示欠费隔离
TERMINATING：表示销毁中。
TERMINATED：表示已销毁
注意：此字段可能返回 null，表示取不到有效值。
   */
  InstanceState?: string
  /**
   * 应用名称

注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationName?: string
  /**
   * 算力套餐名称

注意：此字段可能返回 null，表示取不到有效值。
   */
  BundleName?: string
  /**
   * 实例所包含的GPU卡数
注意：此字段可能返回 null，表示取不到有效值。
   */
  GPUCount?: number
  /**
   * 算力

注意：此字段可能返回 null，表示取不到有效值。
   */
  GPUPerformance?: string
  /**
   * 显存
注意：此字段可能返回 null，表示取不到有效值。
   */
  GPUMemory?: string
  /**
   * CPU核数
注意：此字段可能返回 null，表示取不到有效值。
   */
  CPU?: string
  /**
   * 内存

注意：此字段可能返回 null，表示取不到有效值。
   */
  Memory?: string
  /**
   * 系统盘数据
注意：此字段可能返回 null，表示取不到有效值。
   */
  SystemDisk?: SystemDisk
  /**
   * 内网ip地址
注意：此字段可能返回 null，表示取不到有效值。
   */
  PrivateIpAddresses?: Array<string>
  /**
   * 公网ip地址
注意：此字段可能返回 null，表示取不到有效值。
   */
  PublicIpAddresses?: Array<string>
  /**
   * 安全组ID

注意：此字段可能返回 null，表示取不到有效值。
   */
  SecurityGroupIds?: Array<string>
  /**
   * 实例最新操作
注意：此字段可能返回 null，表示取不到有效值。
   */
  LatestOperation?: string
  /**
   * 实例最新操作状态：
SUCCESS：表示操作成功
OPERATING：表示操作执行中
FAILED：表示操作失败

注意：此字段可能返回 null，表示取不到有效值。
   */
  LatestOperationState?: string
  /**
   * 实例创建时间
注意：此字段可能返回 null，表示取不到有效值。
   */
  CreateTime?: string
  /**
   * 公网出带宽上限，默认10Mbps
注意：此字段可能返回 null，表示取不到有效值。
   */
  MaxOutBandwidth?: string
  /**
   * 每月免费流量，默认500G
注意：此字段可能返回 null，表示取不到有效值。
   */
  MaxFreeTraffic?: string
  /**
   * 应用配置环境
注意：此字段可能返回 null，表示取不到有效值。
   */
  ConfigurationEnvironment?: string
  /**
   * 实例包含的登录服务详情
注意：此字段可能返回 null，表示取不到有效值。
   */
  LoginServices?: Array<LoginService>
  /**
   * 应用服务的操作系统类型
注意：此字段可能返回 null，表示取不到有效值。
   */
  OSType?: string
}

/**
 * TerminateInstances返回参数结构体
 */
export interface TerminateInstancesResponse {
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeRegions请求参数结构体
 */
export type DescribeRegionsRequest = null

/**
 * StartInstance请求参数结构体
 */
export interface StartInstanceRequest {
  /**
   * 实例ID
   */
  InstanceId: string
  /**
   * 默认为False，True代表只验证接口连通性
   */
  DryRun?: boolean
}

/**
 * 某服务的登录配置
 */
export interface LoginSetting {
  /**
   * 服务名称
注意：此字段可能返回 null，表示取不到有效值。
   */
  ServiceName?: string
  /**
   * 服务登录url
注意：此字段可能返回 null，表示取不到有效值。
   */
  Url?: string
}

/**
 * 费用数据结构体
 */
export interface Price {
  /**
   * 实例价格信息
注意：此字段可能返回 null，表示取不到有效值。
   */
  InstancePrice?: ItemPrice
  /**
   * 云盘价格信息
注意：此字段可能返回 null，表示取不到有效值。
   */
  CloudDiskPrice?: ItemPrice
}

/**
 * TerminateInstances请求参数结构体
 */
export interface TerminateInstancesRequest {
  /**
   * 实例ID列表
   */
  InstanceIds: Array<string>
  /**
   * 默认为False，True代表只验证接口连通性
   */
  DryRun?: boolean
}

/**
 * 地域列表
 */
export interface RegionInfo {
  /**
   * ap-guangzhou

注意：此字段可能返回 null，表示取不到有效值。
   */
  Region?: string
  /**
   * 华南地区(广州)
注意：此字段可能返回 null，表示取不到有效值。
   */
  RegionName?: string
  /**
   * 地域是否可用状态
AVAILABLE：可用

注意：此字段可能返回 null，表示取不到有效值。
   */
  RegionState?: string
  /**
   * 学术加速是否支持：
NO_NEED_SUPPORT表示不需支持；NOT_SUPPORT_YET表示暂未支持；ALREADY_SUPPORT表示已经支持。对于ALREADY_SUPPORT的地域才需进一步调用DescribeScholarRocketStatus查看学术加速是开启还是关闭
注意：此字段可能返回 null，表示取不到有效值。
   */
  ScholarRocketSupportState?: string
}

/**
 * DescribeScenes返回参数结构体
 */
export interface DescribeScenesResponse {
  /**
   * 场景详情
注意：此字段可能返回 null，表示取不到有效值。
   */
  SceneSet?: Array<SceneInfo>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeApplications请求参数结构体
 */
export interface DescribeApplicationsRequest {
  /**
   * 应用id列表
   */
  ApplicationIds?: Array<string>
  /**
   * 过滤器，跟ApplicationIds不能共用，支持的filter主要有：
application-id: 精确匹配;
scene-id: 精确匹配;
application-name: 模糊匹配;
application-type: 精确匹配;
   */
  Filters?: Array<Filter>
  /**
   * 偏移量，默认为0
   */
  Offset?: number
  /**
   * 返回量，默认为20
MC：1000
用户：100

   */
  Limit?: number
  /**
   * 应用列表排序的依据字段。取值范围："CREATED_TIME"：依据应用的创建时间排序。 "APPLICATION_SIZE"：依据应用的大小排序。默认按应用的创建时间排序。
   */
  OrderField?: string
  /**
   * 输出应用列表的排列顺序。取值范围："ASC"：升序排列。 "DESC"：降序排列。默认按降序排列。
   */
  Order?: string
}

/**
 * RunInstances请求参数结构体
 */
export interface RunInstancesRequest {
  /**
   * 应用ID
   */
  ApplicationId: string
  /**
   * 算力套餐类型
   */
  BundleType: string
  /**
   * 实例系统盘配置信息。若不指定该参数，则按照系统默认值进行分配。
   */
  SystemDisk?: SystemDisk
  /**
   * 购买实例数量。
   */
  InstanceCount?: number
  /**
   * 实例显示名称
   */
  InstanceName?: string
  /**
   * 幂等请求的token
   */
  ClientToken?: string
  /**
   * DryRun为True就是只验接口连通性，默认为False
   */
  DryRun?: boolean
}

/**
 * DescribeInstances返回参数结构体
 */
export interface DescribeInstancesResponse {
  /**
   * 实例总数

注意：此字段可能返回 null，表示取不到有效值。
   */
  TotalCount?: number
  /**
   * 分页实例详情

注意：此字段可能返回 null，表示取不到有效值。
   */
  InstanceSet?: Array<Instance>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 描述了操作系统所在块设备即系统盘的信息
 */
export interface SystemDisk {
  /**
   * 系统盘类型。系统盘类型限制详见[存储概述](https://cloud.tencent.com/document/product/213/4952)。取值范围：<br><li>LOCAL_BASIC：本地硬盘<br><li>LOCAL_SSD：本地SSD硬盘<br><li>CLOUD_BASIC：普通云硬盘<br><li>CLOUD_SSD：SSD云硬盘<br><li>CLOUD_PREMIUM：高性能云硬盘<br><li>CLOUD_BSSD：通用性SSD云硬盘<br><br>默认取值：当前有库存的硬盘类型。	
注意：此字段可能返回 null，表示取不到有效值。
   */
  DiskType?: string
  /**
   * 系统盘大小，单位：GB。默认值为 80
注意：此字段可能返回 null，表示取不到有效值。
   */
  DiskSize?: number
  /**
   * 系统盘分区盘符
注意：此字段可能返回 null，表示取不到有效值。
   */
  DiskName?: string
}

/**
 * RunInstances返回参数结构体
 */
export interface RunInstancesResponse {
  /**
   * 实例ID列表
   */
  InstanceIdSet?: Array<string>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeInstances请求参数结构体
 */
export interface DescribeInstancesRequest {
  /**
   * 实例元组
   */
  InstanceIds?: Array<string>
  /**
   * 描述键值对过滤器，用于条件过滤查询。目前支持的过滤器有：instance-id，实例id；instance-state，实例状态
   */
  Filters?: Array<Filter>
  /**
   * 偏移量，默认为0

   */
  Offset?: number
  /**
   * 返回量，默认为20
   */
  Limit?: number
}

/**
 * 描述键值对过滤器，用于条件过滤查询。例如过滤ID、名称、状态等

- 若存在多个Filter时，Filter间的关系为逻辑与（AND）关系。
- 若同一个Filter存在多个Values，同一Filter下Values间的关系为逻辑或（OR）关系。
 */
export interface Filter {
  /**
   * 需要过滤的字段。
   */
  Name: string
  /**
   * 字段的过滤值。
   */
  Values: Array<string>
}

/**
 * DescribeScenes请求参数结构体
 */
export interface DescribeScenesRequest {
  /**
   * 场景id列表
   */
  SceneIds?: Array<string>
}

/**
 * DescribeRegions返回参数结构体
 */
export interface DescribeRegionsResponse {
  /**
   * 地域列表
注意：此字段可能返回 null，表示取不到有效值。
   */
  RegionSet?: Array<RegionInfo>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * InquirePriceRunInstances请求参数结构体
 */
export interface InquirePriceRunInstancesRequest {
  /**
   * 应用ID
   */
  ApplicationId: string
  /**
   * 算力套餐类型
   */
  BundleType: string
  /**
   * 实例系统盘配置信息。若不指定该参数，则按照系统默认值进行分配。
   */
  SystemDisk?: SystemDisk
  /**
   * 购买实例数量。
   */
  InstanceCount?: number
  /**
   * 实例显示名称
   */
  InstanceName?: string
  /**
   * 幂等请求token
   */
  ClientToken?: string
  /**
   * DryRun为True就是只验接口连通性，默认为False
   */
  DryRun?: boolean
}

/**
 * StartInstance返回参数结构体
 */
export interface StartInstanceResponse {
  /**
   * task任务id
   */
  TaskId?: number
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * DescribeServiceLoginSettings请求参数结构体
 */
export interface DescribeServiceLoginSettingsRequest {
  /**
   * 实例id
   */
  InstanceId: string
  /**
   * 服务名称
   */
  ServiceName?: string
}

/**
 * 应用信息
 */
export interface ApplicationInfo {
  /**
   * 应用id

注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationId?: string
  /**
   * 应用名称
注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationName?: string
  /**
   * 应用描述

注意：此字段可能返回 null，表示取不到有效值。
   */
  Description?: string
  /**
   * 应用的环境配置
注意：此字段可能返回 null，表示取不到有效值。
   */
  ConfigEnvironment?: string
  /**
   * 系统盘大小下限
注意：此字段可能返回 null，表示取不到有效值。
   */
  MinSystemDiskSize?: number
  /**
   * 应用类型，目前该项取值可以为PRIVATE_APPLICATION或者PUBLIC_APPLICATION
注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationType?: string
  /**
   * 应用状态：CREATING-创建中；ONLINE -正常在线；DELETING -删除中；ARREARS - 欠费隔离
示例值：ONLINE
注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationState?: string
  /**
   * 应用创建时间
注意：此字段可能返回 null，表示取不到有效值。
   */
  CreateTime?: string
  /**
   * 应用大小
注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationSize?: number
}

/**
 * DescribeApplications返回参数结构体
 */
export interface DescribeApplicationsResponse {
  /**
   * 应用总数
注意：此字段可能返回 null，表示取不到有效值。
   */
  TotalCount?: number
  /**
   * 分页返回的应用列表
注意：此字段可能返回 null，表示取不到有效值。
   */
  ApplicationSet?: Array<ApplicationInfo>
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 套餐价格
 */
export interface ItemPrice {
  /**
   * 原单价
注意：此字段可能返回 null，表示取不到有效值。
   */
  UnitPrice?: number
  /**
   * 折扣后单价
注意：此字段可能返回 null，表示取不到有效值。
   */
  DiscountUnitPrice?: number
  /**
   * 折扣
注意：此字段可能返回 null，表示取不到有效值。
   */
  Discount?: number
  /**
   * 单位：时

注意：此字段可能返回 null，表示取不到有效值。
   */
  ChargeUnit?: string
  /**
   * 商品数量
注意：此字段可能返回 null，表示取不到有效值。
   */
  Amount?: number
}

/**
 * DescribeInstanceNetworkStatus请求参数结构体
 */
export interface DescribeInstanceNetworkStatusRequest {
  /**
   * 实例ID数组，单次请求最多不超过100个实例
   */
  InstanceIds: Array<string>
}

/**
 * 登录服务详情
 */
export interface LoginService {
  /**
   * 登录方式名称
注意：此字段可能返回 null，表示取不到有效值。
   */
  ServiceName?: string
}

/**
 * StopInstance返回参数结构体
 */
export interface StopInstanceResponse {
  /**
   * task任务id
   */
  TaskId?: number
  /**
   * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
   */
  RequestId?: string
}

/**
 * 场景详情
 */
export interface SceneInfo {
  /**
   * 场景id

注意：此字段可能返回 null，表示取不到有效值。
   */
  SceneId?: string
  /**
   * 场景名

注意：此字段可能返回 null，表示取不到有效值。
   */
  SceneName?: string
}
